import { ControlValueAccessor } from '@angular/forms';
import { QueryOperatorDirective } from './query-operator.directive';
import { QueryFieldDirective } from './query-field.directive';
import { QuerySwitchGroupDirective } from './query-switch-group.directive';
import { QueryButtonGroupDirective } from './query-button-group.directive';
import { QueryInputDirective } from './query-input.directive';
import { QueryRemoveButtonDirective } from './query-remove-button.directive';
import { ButtonGroupContext, Field, FieldContext, InputContext, LocalRuleMeta, OperatorContext, RemoveButtonContext, Option, QueryBuilderConfig, Rule, RuleSet } from './query-builder.interfaces';
import { ChangeDetectorRef, OnChanges, OnInit, QueryList, SimpleChanges, TemplateRef } from '@angular/core';
export declare const CONTROL_VALUE_ACCESSOR: any;
export declare class QueryBuilderComponent implements OnInit, OnChanges, ControlValueAccessor {
    private changeDetectorRef;
    disabled: boolean;
    fields: Field[];
    defaultClassNames: {
        [key: string]: string;
    };
    defaultOperatorMap: {
        [key: string]: string[];
    };
    allowRuleset: boolean;
    classNames: {
        [key: string]: string;
    };
    operatorMap: {
        [key: string]: string[];
    };
    data: RuleSet;
    parentData: RuleSet;
    config: QueryBuilderConfig;
    parentInputTemplates: QueryList<QueryInputDirective>;
    parentOperatorTemplate: QueryOperatorDirective;
    parentFieldTemplate: QueryFieldDirective;
    parentSwitchGroupTemplate: QuerySwitchGroupDirective;
    parentButtonGroupTemplate: QueryButtonGroupDirective;
    parentRemoveButtonTemplate: QueryRemoveButtonDirective;
    buttonGroupTemplate: QueryButtonGroupDirective;
    switchGroupTemplate: QuerySwitchGroupDirective;
    fieldTemplate: QueryFieldDirective;
    operatorTemplate: QueryOperatorDirective;
    removeButtonTemplate: QueryRemoveButtonDirective;
    inputTemplates: QueryList<QueryInputDirective>;
    private defaultTemplateTypes;
    private defaultEmptyList;
    private operatorsCache;
    private inputContextCache;
    private operatorContextCache;
    private fieldContextCache;
    private removeButtonContextCache;
    private buttonGroupContext;
    private onChangeCallback;
    private onTouchedCallback;
    constructor(changeDetectorRef: ChangeDetectorRef);
    ngOnInit(): void;
    ngOnChanges(changes: SimpleChanges): void;
    value: RuleSet;
    writeValue(obj: any): void;
    registerOnChange(fn: any): void;
    registerOnTouched(fn: any): void;
    setDisabledState(isDisabled: boolean): void;
    findTemplateForRule(rule: Rule): TemplateRef<any>;
    findQueryInput(type: string): QueryInputDirective;
    getOperators(field: string): string[];
    getInputType(field: string, operator: string): string;
    getOptions(field: string): Option[];
    getClassName(id: string): string;
    getDefaultOperator(field: Field): any;
    addRule(parent?: RuleSet): void;
    removeRule(rule: Rule, parent?: RuleSet): void;
    addRuleSet(parent?: RuleSet): void;
    removeRuleSet(ruleset?: RuleSet, parent?: RuleSet): void;
    changeField(fieldValue: string, rule: Rule): void;
    getDefaultValue(defaultValue: any): any;
    getOperatorTemplate(): TemplateRef<any>;
    getFieldTemplate(): TemplateRef<any>;
    getButtonGroupTemplate(): TemplateRef<any>;
    getSwitchGroupTemplate(): TemplateRef<any>;
    getRemoveButtonTemplate(): TemplateRef<any>;
    getQueryItemClassName(local: LocalRuleMeta): string;
    getButtonGroupContext(): ButtonGroupContext;
    getRemoveButtonContext(rule: Rule): RemoveButtonContext;
    getFieldContext(rule: Rule): FieldContext;
    getOperatorContext(rule: Rule): OperatorContext;
    getInputContext(rule: Rule): InputContext;
}
